import { useTheme } from '@mui/material';
import React, { useState } from 'react';
import { Handle, Position } from 'react-flow-renderer';
import { Handles } from '../entitypill/entitypill';
import styles from './attributepill.module.scss';

/**
 * Component to render an attribute flow element
 * @param {FlowElement<EntityData>)} param0 The data of an entity flow element.
 */
export const AttributeRFPill = React.memo(({ data }: { data: any }) => {
  const theme = useTheme();
  const [readonly, setReadonly] = useState(true);
  const [value, setValue] = useState(data?.value || '');

  /** Checks if the string input is a number. */
  const isNumber = (x: string): boolean => {
    {
      if (typeof x != 'string') return false;
      return !Number.isNaN(x) && !Number.isNaN(parseFloat(x));
    }
  };

  /** Checks if the provided value is the same as the datatype of the attribute. */
  const inputConstraint = (type: string, str: string): string => {
    let res = '';
    switch (type) {
      case 'string':
        res = str;
        break;
      case 'bool':
        res = str;
        break; // TODO: only false and true live update will break since it will not allow to write more that 1 letter
      case 'int':
        isNumber(str) ? (res = str) : (res = '');
        break; // TODO: check if letters after number
      default:
        res = str;
        break;
    }
    return res;
  };

  const onChange = (e: any) => {
    if (data != undefined) {
      setValue(inputConstraint(data.datatype, e.target.value));
    }
  };

  // Calculates the size of the input
  const getInputWidth = () => {
    if (value == '') return 1;
    else if (value.length > 10) return 10;
    return value.length;
  };

  return (
    <div
      className={styles.attribute}
      style={{
        background: theme.palette.queryBuilder.attribute.background,
        color: theme.palette.queryBuilder.text,
      }}
    >
      {/* <Handle
        id={Handles.Attribute}
        type="source"
        position={Position.Bottom}
        className={styles.handle}
      /> */}
      <div className={styles.contentWrapper}>
        <span className={styles.content}>{data.name}</span>
        <span className={styles.attributeInput}>
          <input
            style={{ maxWidth: `${getInputWidth()}ch` }}
            type="string"
            // readOnly={readonly}
            placeholder={'?'}
            value={value}
            onChange={onChange}
            // onDoubleClick={() => setReadonly(false)}
            // onBlur={() => setReadonly(true)}
            onKeyDown={(e) => e.key == 'Enter' && setReadonly(true)}
          ></input>
        </span>
      </div>
    </div>
  );
});

export default AttributeRFPill;
