import { useTheme } from '@mui/material';
import React, { useEffect } from 'react';
import { FlowElement, Handle, Position } from 'react-flow-renderer';
import styles from './entitypill.module.scss';

// export const Handless = {
//   entity: {
//     attributes: 'attributesHandle',
//     relations: 'relationsHandle',
//   },
// };

/** Links need handles to what they are connected to (and which side) */
export enum Handles {
  RelationLeft = 'leftEntityHandle', //target
  RelationRight = 'rightEntityHandle', //target
  ToAttributeHandle = 'attributesHandle', //target
  ToRelation = 'relationsHandle', //source
  Attribute = 'AttributeHandle', //source
  ReceiveFunction = 'receiveFunctionHandle', //target
  FunctionBase = 'functionHandle_', // + name from FunctionTypes args //source
}

/**
 * Component to render an entity flow element
 * @param {FlowElement<EntityData>)} param0 The data of an entity flow element.
 */
export const EntityRFPill = React.memo(({ data }: { data: any }) => {
  const theme = useTheme();

  return (
    <div
      className={styles.entity}
      style={{
        background: theme.palette.queryBuilder.entity.background,
        color: theme.palette.queryBuilder.text,
      }}
    >
      <Handle
        id={Handles.ToRelation}
        type="source"
        position={Position.Bottom}
        className={styles.handleLeft}
      />
      <Handle
        id={Handles.ToAttributeHandle}
        type="target"
        position={Position.Bottom}
        className={styles.handleBottom}
      />
      <div className={styles.contentWrapper}>
        <span>{data.name}</span>
      </div>
    </div>
  );
});

export default EntityRFPill;
